"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const tableCore = require("@tanstack/table-core");
const vue = require("vue");
const mergeProxy = require("./merge-proxy.cjs");
const FlexRender = vue.defineComponent({
  props: ["render", "props"],
  setup: (props) => {
    return () => {
      if (typeof props.render === "function" || typeof props.render === "object") {
        return vue.h(props.render, props.props);
      }
      return props.render;
    };
  }
});
function useVueTable(options) {
  const resolvedOptions = mergeProxy.mergeProxy(
    {
      state: {},
      // Dummy state
      onStateChange: () => {
      },
      // noop
      renderFallbackValue: null,
      mergeOptions(defaultOptions, options2) {
        return mergeProxy.mergeProxy(defaultOptions, options2);
      }
    },
    options
  );
  const table = tableCore.createTable(resolvedOptions);
  const state = vue.ref(table.initialState);
  vue.watchEffect(() => {
    table.setOptions((prev) => {
      const stateProxy = new Proxy({}, {
        get: (_, prop) => state.value[prop]
      });
      return mergeProxy.mergeProxy(prev, options, {
        // merge the initialState and `options.state`
        // create a new proxy on each `setOptions` call
        // and get the value from state on each property access
        state: mergeProxy.mergeProxy(stateProxy, options.state ?? {}),
        // Similarly, we'll maintain both our internal state and any user-provided
        // state.
        onStateChange: (updater) => {
          var _a;
          if (updater instanceof Function) {
            state.value = updater(state.value);
          } else {
            state.value = updater;
          }
          (_a = options.onStateChange) == null ? void 0 : _a.call(options, updater);
        }
      });
    });
  });
  return table;
}
exports.FlexRender = FlexRender;
exports.useVueTable = useVueTable;
Object.keys(tableCore).forEach((k) => {
  if (k !== "default" && !Object.prototype.hasOwnProperty.call(exports, k))
    Object.defineProperty(exports, k, {
      enumerable: true,
      get: () => tableCore[k]
    });
});
//# sourceMappingURL=index.cjs.map
