import { createTable } from "@tanstack/table-core";
export * from "@tanstack/table-core";
import { defineComponent, h, ref, watchEffect } from "vue";
import { mergeProxy } from "./merge-proxy.js";
const FlexRender = defineComponent({
  props: ["render", "props"],
  setup: (props) => {
    return () => {
      if (typeof props.render === "function" || typeof props.render === "object") {
        return h(props.render, props.props);
      }
      return props.render;
    };
  }
});
function useVueTable(options) {
  const resolvedOptions = mergeProxy(
    {
      state: {},
      // Dummy state
      onStateChange: () => {
      },
      // noop
      renderFallbackValue: null,
      mergeOptions(defaultOptions, options2) {
        return mergeProxy(defaultOptions, options2);
      }
    },
    options
  );
  const table = createTable(resolvedOptions);
  const state = ref(table.initialState);
  watchEffect(() => {
    table.setOptions((prev) => {
      const stateProxy = new Proxy({}, {
        get: (_, prop) => state.value[prop]
      });
      return mergeProxy(prev, options, {
        // merge the initialState and `options.state`
        // create a new proxy on each `setOptions` call
        // and get the value from state on each property access
        state: mergeProxy(stateProxy, options.state ?? {}),
        // Similarly, we'll maintain both our internal state and any user-provided
        // state.
        onStateChange: (updater) => {
          var _a;
          if (updater instanceof Function) {
            state.value = updater(state.value);
          } else {
            state.value = updater;
          }
          (_a = options.onStateChange) == null ? void 0 : _a.call(options, updater);
        }
      });
    });
  });
  return table;
}
export {
  FlexRender,
  useVueTable
};
//# sourceMappingURL=index.js.map
